@@ -1,10 +1,10 @@
 # Copyrights 1999,2001-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 package MIME::Type;
 use vars '$VERSION';
-$VERSION = '1.38';
+$VERSION = '2.00';
 
 
 use strict;
@@ -15,9 +15,7 @@ use Carp 'croak';
 #-------------------------------------------
 
 
-use overload '""' => 'type'
-           ,  cmp => 'equals'
-           ;
+use overload '""' => 'type', cmp => 'equals';
 
 #-------------------------------------------
 
@@ -27,11 +25,11 @@ sub new(@) { (bless {}, shift)->init( {@_} ) }
 sub init($)
 {   my ($self, $args) = @_;
 
-    $self->{MT_type}       = $args->{type}
+    my $type = $self->{MT_type}       = $args->{type}
        or croak "ERROR: Type parameter is obligatory.";
 
     $self->{MT_simplified} = $args->{simplified}
-       || ref($self)->simplified($args->{type});
+       || $self->simplified($type);
 
     $self->{MT_extensions} = $args->{extensions} || [];
 
@@ -59,7 +57,7 @@ sub simplified(;$)
     my $mime  = shift;
 
       $mime =~ m!^\s*(?:x\-)?([\w.+-]+)/(?:x\-)?([\w.+-]+)\s*$!i ? lc "$1/$2"
-    : $mime =~ m!text! ? "text/plain"         # some silly mailers...
+    : $mime eq 'text' ? 'text/plain'          # some silly mailers...
     : undef;
 }
 
@@ -82,20 +80,21 @@ sub mainType()  {shift->mediaType} # Backwards compatibility
 sub subType() {shift->{MT_simplified} =~ m!/([\w+.-]+)$! ? $1 : undef}
 
 
-sub isRegistered()
-{   local $_ = shift->{MT_type};
-    not (m/^[xX]\-/ || m!/[xX]\-!);
-}
+sub isRegistered() { lc shift->{MT_type} !~ m{^x\-|/x\-} }
+
+
+# http://tools.ietf.org/html/rfc4288#section-3
+sub isVendor()       {shift->{MT_simplified} =~ m!/vnd\.!}
+sub isPersonal()     {shift->{MT_simplified} =~ m!/prs\.!}
+sub isExperimental() {shift->{MT_simplified} =~ m!/x\.!  }
 
 
 sub isBinary() { shift->{MT_encoding} eq 'base64' }
-
-
-sub isAscii() { shift->{MT_encoding} ne 'base64' }
+sub isAscii()  { shift->{MT_encoding} ne 'base64' }
 
 
 # simplified names only!
-my %sigs = map { ($_ => 1) }
+my %sigs = map +($_ => 1),
   qw(application/pgp-keys application/pgp application/pgp-signature
      application/pkcs10 application/pkcs7-mime application/pkcs7-signature
      text/vCard);
